import { defineComponent, $prefix } from '@opentinyvue/vue-common';
import { iconChevronLeft, iconPlus } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme-mobile/nav-bar/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "NavBar",
  props: {
    tiny_renderless: Function,
    title: String,
    subTitle: String,
    fixed: Boolean,
    zIndex: [Number, String],
    leftText: String,
    rightText: String,
    leftArrow: Boolean,
    rightArrow: Boolean
  },
  components: {
    LeftIcon: iconChevronLeft(),
    RightIcon: iconPlus()
  },
  render: function render() {
    var h = arguments[0];
    var leftArrow = this.leftArrow, rightArrow = this.rightArrow, leftText = this.leftText, rightText = this.rightText, $listeners = this.$listeners, $attrs = this.$attrs, title = this.title, zIndex = this.zIndex, fixed = this.fixed, subTitle = this.subTitle;
    var $slots = "$scopedSlots" in this ? this.$slots : this.$slots;
    function noop() {
    }
    function LeftPart() {
      if ($slots.left) return $slots.left();
      return [leftArrow && h("left-icon", {
        "class": "tiny-mobile-nav-bar__icon left-icon"
      }), leftText && h("span", {
        class: "tiny-mobile-nav-bar__text left-text"
      }, leftText)];
    }
    function RightPart() {
      if ($slots.right) return $slots.right();
      return [rightArrow && h("right-icon", {
        "class": "tiny-mobile-nav-bar__icon right-icon"
      }), rightText && h("span", {
        "class": "tiny-mobile-nav-bar__text right-text"
      }, [rightText])];
    }
    var clickLeftListener = $attrs && $attrs.onClickLeft;
    var clickRightListener = $attrs && $attrs.onClickRight;
    if (!clickLeftListener) {
      clickLeftListener = $listeners && $listeners["click-left"] || noop;
    }
    if (!clickRightListener) {
      clickRightListener = $listeners && $listeners["click-right"] || noop;
    }
    return h("div", {
      "style": {
        zIndex
      },
      "class": {
        "tiny-mobile-nav-bar": true,
        "tiny-mobile-nav-bar__fixed": fixed
      }
    }, [h("div", {
      "class": "tiny-mobile-nav-bar__left",
      "on": {
        "click": clickLeftListener
      }
    }, [LeftPart()]), h("div", {
      "class": "tiny-mobile-nav-bar__title"
    }, [h("p", {
      "class": "main-title"
    }, [$slots.default ? $slots.default() : title]), h("p", {
      "class": {
        "is-show-subtitle": subTitle,
        "sub-title": true
      }
    }, [subTitle])]), h("div", {
      "class": "tiny-mobile-nav-bar__right",
      "on": {
        "click": clickRightListener
      }
    }, [RightPart()])]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var NavBar = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
NavBar.install = function(Vue) {
  Vue.component(NavBar.name, NavBar);
};
NavBar.version = version;

export { NavBar as default };
